{% extends "base.html" %}
{% block body %}
{% include "partials/playbook_card.html" with playbook=host.playbook %}
{% load pygments_highlights %}

<div class="pf-c-card" style="margin: 1em 0;">
    <div class="pf-c-card__header pf-c-title pf-m-md">
        Host: {{ host.name }}
    </div>
    <div class="pf-c-card__body">
        <table class="pf-c-table pf-m-grid-md" role="grid">
            <thead>
                <tr>
                    <th>Fact</th>
                    <th>Value</th>
                </tr>
            </thead>
            <tbody>
                {% for fact, value in host.facts.items %}
                <tr>
                    <td id="{{ fact }}" style="white-space: nowrap"><a href="#{{ fact }}">{{ fact }}</a></td>
                    <td>{{ value | format_data | safe }}</td>
                </tr>
                {% endfor %}
            </tbody>
        </table>
    </div>
</div>
{% endblock %}